@@ -17,6 +17,7 @@
 
 package org.apache.doris.flink.sink.copy;
 
+import org.apache.flink.annotation.VisibleForTesting;
 import org.apache.flink.api.connector.sink2.Sink;
 import org.apache.flink.runtime.checkpoint.CheckpointIDCounter;
 import org.apache.flink.util.Preconditions;
@@ -194,4 +195,9 @@ public class DorisCopyWriter<IN>
             throw new RuntimeException("Writing records to streamload failed.", flushException);
         }
     }
+
+    @VisibleForTesting
+    public BatchStageLoad getBatchStageLoad() {
+        return batchStageLoad;
+    }
 }
