@@ -20,8 +20,10 @@ package org.apache.doris.flink.sink.schema;
 import org.apache.flink.util.CollectionUtil;
 import org.apache.flink.util.StringUtils;
 
+import com.fasterxml.jackson.core.JsonProcessingException;
 import com.fasterxml.jackson.databind.JsonNode;
 import com.fasterxml.jackson.databind.ObjectMapper;
+import com.fasterxml.jackson.databind.node.NullNode;
 import org.apache.commons.codec.binary.Base64;
 import org.apache.doris.flink.catalog.doris.DorisSystem;
 import org.apache.doris.flink.catalog.doris.FieldSchema;
@@ -122,11 +124,30 @@ public class SchemaChangeManager implements Serializable {
             throws IOException, IllegalArgumentException {
         if (!checkColumnExists(database, table, field.getName())) {
             LOG.warn(
-                    "The column {} is not exists in table {}, can not modify it type",
+                    "The column {} is not exists in table {}, can not modify it's type",
                     field.getName(),
                     table);
             return false;
         }
+
+        String ddl = SchemaChangeHelper.buildShowFullColumnDDL(database, table);
+        String defaultValue = getDefaultValue(ddl, database, field.getName());
+        if (!StringUtils.isNullOrWhitespaceOnly(field.getDefaultValue())) {
+            // Can not change default value
+            if (!field.getDefaultValue().equals(defaultValue)) {
+                LOG.warn(
+                        "Column:{} can not change default value from {} to {}, fallback it",
+                        field.getName(),
+                        defaultValue,
+                        field.getDefaultValue());
+                field.setDefaultValue(defaultValue);
+            }
+        } else {
+            // If user does not give a default value, need fill it from
+            // original table schema to avoid change type failed if default value exists
+            field.setDefaultValue(defaultValue);
+        }
+
         // If user does not give a comment, need fill it from
         // original table schema to avoid miss comment
         if (StringUtils.isNullOrWhitespaceOnly(field.getComment())) {
@@ -198,12 +219,12 @@ public class SchemaChangeManager implements Serializable {
         httpGet.setHeader(HttpHeaders.AUTHORIZATION, authHeader());
         httpGet.setEntity(
                 new StringEntity(objectMapper.writeValueAsString(params), charsetEncoding));
-        String responseEntity = "";
-        Map<String, Object> responseMap = handleResponse(httpGet, responseEntity);
-        return handleSchemaChange(responseMap, responseEntity);
+        String responseEntity = handleResponse(httpGet);
+        return handleSchemaChange(responseEntity);
     }
 
-    private boolean handleSchemaChange(Map<String, Object> responseMap, String responseEntity) {
+    private boolean handleSchemaChange(String responseEntity) throws JsonProcessingException {
+        Map<String, Object> responseMap = objectMapper.readValue(responseEntity, Map.class);
         String code = responseMap.getOrDefault("code", "-1").toString();
         if (code.equals("0")) {
             return true;
@@ -213,17 +234,43 @@ public class SchemaChangeManager implements Serializable {
         }
     }
 
+    private String getDefaultValue(String ddl, String database, String column)
+            throws IOException, IllegalArgumentException {
+        String responseEntity = executeThenReturnResponse(ddl, database);
+        JsonNode responseNode = objectMapper.readTree(responseEntity);
+        String code = responseNode.get("code").asText("-1");
+        if (code.equals("0")) {
+            JsonNode data = responseNode.get("data").get("data");
+            for (JsonNode node : data) {
+                if (node.get(0).asText().equals(column)) {
+                    JsonNode defaultValueNode = node.get(5);
+                    return (defaultValueNode instanceof NullNode)
+                            ? null
+                            : defaultValueNode.asText();
+                }
+            }
+            return null;
+        } else {
+            throw new DorisSchemaChangeException(
+                    "Failed to get default value, response: " + responseEntity);
+        }
+    }
+
     /** execute sql in doris. */
-    public boolean execute(String ddl, String database)
+    private String executeThenReturnResponse(String ddl, String database)
             throws IOException, IllegalArgumentException {
         if (StringUtils.isNullOrWhitespaceOnly(ddl)) {
-            return false;
+            throw new IllegalArgumentException("ddl can not be null or empty string!");
         }
         LOG.info("Execute SQL: {}", ddl);
         HttpPost httpPost = buildHttpPost(ddl, database);
-        String responseEntity = "";
-        Map<String, Object> responseMap = handleResponse(httpPost, responseEntity);
-        return handleSchemaChange(responseMap, responseEntity);
+        return handleResponse(httpPost);
+    }
+
+    public boolean execute(String ddl, String database)
+            throws IOException, IllegalArgumentException {
+        String responseEntity = executeThenReturnResponse(ddl, database);
+        return handleSchemaChange(responseEntity);
     }
 
     public HttpPost buildHttpPost(String ddl, String database)
@@ -245,15 +292,13 @@ public class SchemaChangeManager implements Serializable {
         return httpPost;
     }
 
-    private Map<String, Object> handleResponse(HttpUriRequest request, String responseEntity) {
+    private String handleResponse(HttpUriRequest request) {
         try (CloseableHttpClient httpclient = HttpClients.createDefault()) {
             CloseableHttpResponse response = httpclient.execute(request);
             final int statusCode = response.getStatusLine().getStatusCode();
             final String reasonPhrase = response.getStatusLine().getReasonPhrase();
             if (statusCode == 200 && response.getEntity() != null) {
-                responseEntity = EntityUtils.toString(response.getEntity());
-                Map<String, Object> responseMap = objectMapper.readValue(responseEntity, Map.class);
-                return responseMap;
+                return EntityUtils.toString(response.getEntity());
             } else {
                 throw new DorisSchemaChangeException(
                         "Failed to schemaChange, status: "
