@@ -19,7 +19,6 @@ package org.apache.doris.flink.sink.writer.serializer.jsondebezium;
 
 import org.apache.flink.annotation.VisibleForTesting;
 import org.apache.flink.api.java.tuple.Tuple2;
-import org.apache.flink.util.CollectionUtil;
 import org.apache.flink.util.Preconditions;
 import org.apache.flink.util.StringUtils;
 
@@ -27,7 +26,7 @@ import com.fasterxml.jackson.core.JsonProcessingException;
 import com.fasterxml.jackson.core.type.TypeReference;
 import com.fasterxml.jackson.databind.JsonNode;
 import org.apache.commons.collections.CollectionUtils;
-import org.apache.doris.flink.catalog.doris.DataModel;
+import org.apache.doris.flink.catalog.doris.DorisSchemaFactory;
 import org.apache.doris.flink.catalog.doris.FieldSchema;
 import org.apache.doris.flink.catalog.doris.TableSchema;
 import org.apache.doris.flink.exception.IllegalArgumentException;
@@ -38,18 +37,12 @@ import org.apache.doris.flink.sink.schema.SchemaChangeHelper;
 import org.apache.doris.flink.sink.schema.SchemaChangeHelper.DDLSchema;
 import org.apache.doris.flink.sink.schema.SchemaChangeManager;
 import org.apache.doris.flink.sink.writer.EventType;
-import org.apache.doris.flink.tools.cdc.DatabaseSync;
 import org.apache.doris.flink.tools.cdc.SourceConnector;
-import org.apache.doris.flink.tools.cdc.mysql.MysqlType;
-import org.apache.doris.flink.tools.cdc.oracle.OracleType;
-import org.apache.doris.flink.tools.cdc.postgres.PostgresType;
-import org.apache.doris.flink.tools.cdc.sqlserver.SqlServerType;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import java.io.IOException;
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.LinkedHashMap;
@@ -74,12 +67,7 @@ public class JsonDebeziumSchemaChangeImplV2 extends JsonDebeziumSchemaChange {
                     Pattern.CASE_INSENSITIVE);
     // schemaChange saves table names, field, and field column information
     private Map<String, Map<String, FieldSchema>> originFieldSchemaMap = new LinkedHashMap<>();
-    private SourceConnector sourceConnector;
     // create table properties
-    private final Map<String, String> tableProperties;
-    private String targetDatabase;
-    private String targetTablePrefix;
-    private String targetTableSuffix;
     private final Set<String> filledTables = new HashSet<>();
 
     public JsonDebeziumSchemaChangeImplV2(JsonDebeziumChangeContext changeContext) {
@@ -89,7 +77,7 @@ public class JsonDebeziumSchemaChangeImplV2 extends JsonDebeziumSchemaChange {
         this.dorisOptions = changeContext.getDorisOptions();
         this.schemaChangeManager = new SchemaChangeManager(dorisOptions);
         this.targetDatabase = changeContext.getTargetDatabase();
-        this.tableProperties = changeContext.getTableProperties();
+        this.dorisTableConfig = changeContext.getDorisTableConf();
         this.tableMapping = changeContext.getTableMapping();
         this.objectMapper = changeContext.getObjectMapper();
         this.targetTablePrefix =
@@ -124,6 +112,7 @@ public class JsonDebeziumSchemaChangeImplV2 extends JsonDebeziumSchemaChange {
 
             EventType eventType = extractEventType(recordRoot);
             if (eventType == null) {
+                LOG.warn("Failed to parse eventType. recordRoot={}", recordRoot);
                 return false;
             }
             if (eventType.equals(EventType.CREATE)) {
@@ -134,46 +123,27 @@ public class JsonDebeziumSchemaChangeImplV2 extends JsonDebeziumSchemaChange {
                     String dorisTbl = getCreateTableIdentifier(recordRoot);
                     changeContext.getTableMapping().put(cdcTbl, dorisTbl);
                     this.tableMapping = changeContext.getTableMapping();
-                    LOG.info("create table ddl status: {}", status);
+                    LOG.info(
+                            "create table ddl status: {}, add tableMapping {},{}",
+                            status,
+                            cdcTbl,
+                            dorisTbl);
                 }
             } else if (eventType.equals(EventType.ALTER)) {
-                // db,table
-                Tuple2<String, String> tuple = getDorisTableTuple(recordRoot);
-                if (tuple == null) {
+                Tuple2<String, String> dorisTableTuple = getDorisTableTuple(recordRoot);
+                if (dorisTableTuple == null) {
+                    LOG.warn("Failed to get doris table tuple. record={}", recordRoot);
                     return false;
                 }
                 List<String> ddlSqlList = extractDDLList(recordRoot);
-                if (CollectionUtils.isEmpty(ddlSqlList)) {
-                    LOG.info("ddl can not do schema change:{}", recordRoot);
-                    return false;
-                }
-                List<DDLSchema> ddlSchemas = SchemaChangeHelper.getDdlSchemas();
-                for (int i = 0; i < ddlSqlList.size(); i++) {
-                    DDLSchema ddlSchema = ddlSchemas.get(i);
-                    String ddlSql = ddlSqlList.get(i);
-                    boolean doSchemaChange = checkSchemaChange(tuple.f0, tuple.f1, ddlSchema);
-                    status = doSchemaChange && schemaChangeManager.execute(ddlSql, tuple.f0);
-                    LOG.info("schema change status:{}, ddl:{}", status, ddlSql);
-                }
-            } else {
-                LOG.info("Unsupported event type {}", eventType);
+                status = executeAlterDDLs(ddlSqlList, recordRoot, dorisTableTuple, status);
             }
         } catch (Exception ex) {
-            LOG.warn("schema change error :", ex);
+            LOG.warn("schema change error : ", ex);
         }
         return status;
     }
 
-    private JsonNode extractTableChange(JsonNode record) throws JsonProcessingException {
-        JsonNode historyRecord = extractHistoryRecord(record);
-        JsonNode tableChanges = historyRecord.get("tableChanges");
-        if (!Objects.isNull(tableChanges)) {
-            JsonNode tableChange = tableChanges.get(0);
-            return tableChange;
-        }
-        return null;
-    }
-
     /** Parse Alter Event. */
     @VisibleForTesting
     public List<String> extractDDLList(JsonNode record) throws IOException {
@@ -181,11 +151,19 @@ public class JsonDebeziumSchemaChangeImplV2 extends JsonDebeziumSchemaChange {
                 JsonDebeziumChangeUtils.getDorisTableIdentifier(record, dorisOptions, tableMapping);
         JsonNode historyRecord = extractHistoryRecord(record);
         String ddl = extractJsonNode(historyRecord, "ddl");
+        extractSourceConnector(record);
+        return parserDebeziumStructure(dorisTable, ddl, record);
+    }
+
+    private List<String> parserDebeziumStructure(String dorisTable, String ddl, JsonNode record)
+            throws JsonProcessingException {
         JsonNode tableChange = extractTableChange(record);
-        EventType eventType = extractEventType(record);
-        if (Objects.isNull(tableChange)
-                || Objects.isNull(ddl)
-                || !eventType.equals(EventType.ALTER)) {
+        if (Objects.isNull(tableChange) || Objects.isNull(ddl)) {
+            LOG.warn(
+                    "tableChange or ddl is empty, cannot do schema change. dorisTable={}, tableChange={}, ddl={}",
+                    dorisTable,
+                    tableChange,
+                    ddl);
             return null;
         }
 
@@ -245,71 +223,20 @@ public class JsonDebeziumSchemaChangeImplV2 extends JsonDebeziumSchemaChange {
         JsonNode columns = tableChange.get("table").get("columns");
         JsonNode comment = tableChange.get("table").get("comment");
         String tblComment = comment == null ? "" : comment.asText();
-        Map<String, FieldSchema> field = new LinkedHashMap<>();
+        Map<String, FieldSchema> fields = new LinkedHashMap<>();
         for (JsonNode column : columns) {
-            buildFieldSchema(field, column);
+            buildFieldSchema(fields, column);
         }
         List<String> pkList = new ArrayList<>();
         for (JsonNode column : pkColumns) {
             String fieldName = column.asText();
             pkList.add(fieldName);
         }
+        String[] dbTable = dorisTable.split("\\.");
+        Preconditions.checkArgument(dbTable.length == 2);
 
-        TableSchema tableSchema = new TableSchema();
-        tableSchema.setFields(field);
-        tableSchema.setKeys(pkList);
-        tableSchema.setDistributeKeys(buildDistributeKeys(pkList, field));
-        tableSchema.setTableComment(tblComment);
-        tableSchema.setProperties(tableProperties);
-        tableSchema.setModel(pkList.isEmpty() ? DataModel.DUPLICATE : DataModel.UNIQUE);
-
-        String[] split = dorisTable.split("\\.");
-        Preconditions.checkArgument(split.length == 2);
-        tableSchema.setDatabase(split[0]);
-        tableSchema.setTable(split[1]);
-        if (tableProperties.containsKey("table-buckets")) {
-            String tableBucketsConfig = tableProperties.get("table-buckets");
-            Map<String, Integer> tableBuckets = DatabaseSync.getTableBuckets(tableBucketsConfig);
-            Integer buckets = getTableSchemaBuckets(tableBuckets, tableSchema.getTable());
-            tableSchema.setTableBuckets(buckets);
-        }
-        return tableSchema;
-    }
-
-    @VisibleForTesting
-    public Integer getTableSchemaBuckets(Map<String, Integer> tableBucketsMap, String tableName) {
-        if (tableBucketsMap != null) {
-            // Firstly, if the table name is in the table-buckets map, set the buckets of the table.
-            if (tableBucketsMap.containsKey(tableName)) {
-                return tableBucketsMap.get(tableName);
-            }
-            // Secondly, iterate over the map to find a corresponding regular expression match,
-            for (Map.Entry<String, Integer> entry : tableBucketsMap.entrySet()) {
-
-                Pattern pattern = Pattern.compile(entry.getKey());
-                if (pattern.matcher(tableName).matches()) {
-                    return entry.getValue();
-                }
-            }
-        }
-        return null;
-    }
-
-    private List<String> buildDistributeKeys(
-            List<String> primaryKeys, Map<String, FieldSchema> fields) {
-        if (!CollectionUtil.isNullOrEmpty(primaryKeys)) {
-            return primaryKeys;
-        }
-        if (!fields.isEmpty()) {
-            Map.Entry<String, FieldSchema> firstField = fields.entrySet().iterator().next();
-            return Collections.singletonList(firstField.getKey());
-        }
-        return new ArrayList<>();
-    }
-
-    private String getCreateTableIdentifier(JsonNode record) {
-        String table = extractJsonNode(record.get("source"), "table");
-        return targetDatabase + "." + targetTablePrefix + table + targetTableSuffix;
+        return DorisSchemaFactory.createTableSchema(
+                dbTable[0], dbTable[1], fields, pkList, dorisTableConfig, tblComment);
     }
 
     private boolean checkSchemaChange(String database, String table, DDLSchema ddlSchema)
@@ -320,21 +247,6 @@ public class JsonDebeziumSchemaChangeImplV2 extends JsonDebeziumSchemaChange {
         return schemaChangeManager.checkSchemaChange(database, table, param);
     }
 
-    /** Parse event type. */
-    protected EventType extractEventType(JsonNode record) throws JsonProcessingException {
-        JsonNode tableChange = extractTableChange(record);
-        if (tableChange == null || tableChange.get("type") == null) {
-            return null;
-        }
-        String type = tableChange.get("type").asText();
-        if (EventType.ALTER.toString().equalsIgnoreCase(type)) {
-            return EventType.ALTER;
-        } else if (EventType.CREATE.toString().equalsIgnoreCase(type)) {
-            return EventType.CREATE;
-        }
-        return null;
-    }
-
     private Map<String, Object> extractBeforeRow(JsonNode record) {
         return extractRow(record.get("before"));
     }
@@ -388,7 +300,8 @@ public class JsonDebeziumSchemaChangeImplV2 extends JsonDebeziumSchemaChange {
         }
     }
 
-    private void buildFieldSchema(Map<String, FieldSchema> filedSchemaMap, JsonNode column) {
+    @VisibleForTesting
+    public void buildFieldSchema(Map<String, FieldSchema> filedSchemaMap, JsonNode column) {
         String fieldName = column.get("name").asText();
         String dorisTypeName = buildDorisTypeName(column);
         String defaultValue = handleDefaultValue(extractJsonNode(column, "defaultValueExpression"));
@@ -402,29 +315,12 @@ public class JsonDebeziumSchemaChangeImplV2 extends JsonDebeziumSchemaChange {
         int length = column.get("length") == null ? 0 : column.get("length").asInt();
         int scale = column.get("scale") == null ? 0 : column.get("scale").asInt();
         String sourceTypeName = column.get("typeName").asText();
-        String dorisTypeName;
-        switch (sourceConnector) {
-            case MYSQL:
-                dorisTypeName = MysqlType.toDorisType(sourceTypeName, length, scale);
-                break;
-            case ORACLE:
-                dorisTypeName = OracleType.toDorisType(sourceTypeName, length, scale);
-                break;
-            case POSTGRES:
-                dorisTypeName = PostgresType.toDorisType(sourceTypeName, length, scale);
-                break;
-            case SQLSERVER:
-                dorisTypeName = SqlServerType.toDorisType(sourceTypeName, length, scale);
-                break;
-            default:
-                String errMsg = "Not support " + sourceTypeName + " schema change.";
-                throw new UnsupportedOperationException(errMsg);
-        }
-        return dorisTypeName;
+        return JsonDebeziumChangeUtils.buildDorisTypeName(
+                sourceConnector, sourceTypeName, length, scale);
     }
 
     private String handleDefaultValue(String defaultValue) {
-        if (StringUtils.isNullOrWhitespaceOnly(defaultValue)) {
+        if (defaultValue == null) {
             return null;
         }
         if (defaultValue.equals("1970-01-01 00:00:00")) {
