@@ -94,6 +94,16 @@ public final class DorisDynamicTableSource
             String filterQuery = resolvedFilterQuery.stream().collect(Collectors.joining(" AND "));
             readOptions.setFilterQuery(filterQuery);
         }
+
+        if (StringUtils.isNullOrWhitespaceOnly(readOptions.getReadFields())) {
+            String[] selectFields =
+                    DataType.getFieldNames(physicalRowDataType).toArray(new String[0]);
+            readOptions.setReadFields(
+                    Arrays.stream(selectFields)
+                            .map(item -> String.format("`%s`", item.trim().replace("`", "")))
+                            .collect(Collectors.joining(", ")));
+        }
+
         if (readOptions.getUseOldApi()) {
             List<PartitionDefinition> dorisPartitions;
             try {
@@ -160,9 +170,14 @@ public final class DorisDynamicTableSource
 
     @Override
     public DynamicTableSource copy() {
+        // filterQuery/readFields of readOption may be overwritten in union all sql
         DorisDynamicTableSource newSource =
                 new DorisDynamicTableSource(
-                        options, readOptions, lookupOptions, physicalSchema, physicalRowDataType);
+                        options,
+                        readOptions.copy(),
+                        lookupOptions,
+                        physicalSchema,
+                        physicalRowDataType);
         newSource.resolvedFilterQuery = new ArrayList<>(this.resolvedFilterQuery);
         return newSource;
     }
@@ -199,14 +214,11 @@ public final class DorisDynamicTableSource
     @Override
     public void applyProjection(int[][] projectedFields, DataType producedDataType) {
         this.physicalRowDataType = Projection.of(projectedFields).project(physicalRowDataType);
-        if (StringUtils.isNullOrWhitespaceOnly(readOptions.getReadFields())) {
-            String[] selectFields =
-                    DataType.getFieldNames(physicalRowDataType).toArray(new String[0]);
-            this.readOptions.setReadFields(
-                    Arrays.stream(selectFields)
-                            .map(item -> String.format("`%s`", item.trim().replace("`", "")))
-                            .collect(Collectors.joining(", ")));
-        }
+        String[] selectFields = DataType.getFieldNames(physicalRowDataType).toArray(new String[0]);
+        this.readOptions.setReadFields(
+                Arrays.stream(selectFields)
+                        .map(item -> String.format("`%s`", item.trim().replace("`", "")))
+                        .collect(Collectors.joining(", ")));
     }
 
     @VisibleForTesting
