@@ -28,6 +28,7 @@ import org.apache.flink.util.OutputTag;
 import org.apache.flink.util.Preconditions;
 import org.apache.flink.util.StringUtils;
 
+import org.apache.doris.flink.catalog.doris.DorisSchemaFactory;
 import org.apache.doris.flink.catalog.doris.DorisSystem;
 import org.apache.doris.flink.catalog.doris.TableSchema;
 import org.apache.doris.flink.cfg.DorisConnectionOptions;
@@ -36,6 +37,7 @@ import org.apache.doris.flink.cfg.DorisOptions;
 import org.apache.doris.flink.cfg.DorisReadOptions;
 import org.apache.doris.flink.exception.DorisSystemException;
 import org.apache.doris.flink.sink.DorisSink;
+import org.apache.doris.flink.sink.schema.SchemaChangeMode;
 import org.apache.doris.flink.sink.writer.WriteMode;
 import org.apache.doris.flink.sink.writer.serializer.DorisRecordSerializer;
 import org.apache.doris.flink.sink.writer.serializer.JsonDebeziumSchemaSerializer;
@@ -57,9 +59,10 @@ import java.util.Properties;
 import java.util.Set;
 import java.util.regex.Pattern;
 
+import static org.apache.flink.cdc.debezium.utils.JdbcUrlUtils.PROPERTIES_PREFIX;
+
 public abstract class DatabaseSync {
     private static final Logger LOG = LoggerFactory.getLogger(DatabaseSync.class);
-    private static final String LIGHT_SCHEMA_CHANGE = "light_schema_change";
     private static final String TABLE_NAME_OPTIONS = "table-name";
 
     protected Configuration config;
@@ -70,7 +73,7 @@ public abstract class DatabaseSync {
     protected Pattern includingPattern;
     protected Pattern excludingPattern;
     protected Map<Pattern, String> multiToOneRulesPattern;
-    protected Map<String, String> tableConfig = new HashMap<>();
+    protected DorisTableConfig dorisTableConfig;
     protected Configuration sinkConfig;
     protected boolean ignoreDefaultValue;
     protected boolean ignoreIncompatible;
@@ -78,6 +81,7 @@ public abstract class DatabaseSync {
     public StreamExecutionEnvironment env;
     private boolean createTableOnly = false;
     private boolean newSchemaChange = true;
+    private String schemaChangeMode;
     protected String includingTables;
     protected String excludingTables;
     protected String multiToOneOrigin;
@@ -107,10 +111,6 @@ public abstract class DatabaseSync {
         this.excludingPattern = excludingTables == null ? null : Pattern.compile(excludingTables);
         this.multiToOneRulesPattern = multiToOneRulesParser(multiToOneOrigin, multiToOneTarget);
         this.converter = new TableNameConverter(tablePrefix, tableSuffix, multiToOneRulesPattern);
-        // default enable light schema change
-        if (!this.tableConfig.containsKey(LIGHT_SCHEMA_CHANGE)) {
-            this.tableConfig.put(LIGHT_SCHEMA_CHANGE, "true");
-        }
     }
 
     public void build() throws Exception {
@@ -118,7 +118,9 @@ public abstract class DatabaseSync {
         DorisSystem dorisSystem = new DorisSystem(options);
 
         List<SourceSchema> schemaList = getSchemaList();
-        Preconditions.checkState(!schemaList.isEmpty(), "No tables to be synchronized.");
+        Preconditions.checkState(
+                !schemaList.isEmpty(),
+                "No tables to be synchronized. Please make sure whether the tables that need to be synchronized exist in the corresponding database or schema.");
 
         if (!StringUtils.isNullOrWhitespaceOnly(database)
                 && !dorisSystem.databaseExists(database)) {
@@ -127,13 +129,7 @@ public abstract class DatabaseSync {
         }
         List<String> syncTables = new ArrayList<>();
         List<Tuple2<String, String>> dorisTables = new ArrayList<>();
-        Map<String, Integer> tableBucketsMap = null;
-        if (tableConfig.containsKey("table-buckets")) {
-            tableBucketsMap = getTableBuckets(tableConfig.get("table-buckets"));
-        }
 
-        // Set of table names that have assigned bucket numbers.
-        Set<String> tablesWithBucketsAssigned = new HashSet<>();
         Set<String> targetDbSet = new HashSet<>();
         for (SourceSchema schema : schemaList) {
             syncTables.add(schema.getTableName());
@@ -152,13 +148,9 @@ public abstract class DatabaseSync {
             // Calculate the mapping relationship between upstream and downstream tables
             tableMapping.put(
                     schema.getTableIdentifier(), String.format("%s.%s", targetDb, dorisTable));
-            if (tryCreateTableIfAbsent(
-                    dorisSystem,
-                    targetDb,
-                    dorisTable,
-                    schema,
-                    tableBucketsMap,
-                    tablesWithBucketsAssigned)) {
+            tryCreateTableIfAbsent(dorisSystem, targetDb, dorisTable, schema);
+
+            if (!dorisTables.contains(Tuple2.of(targetDb, dorisTable))) {
                 dorisTables.add(Tuple2.of(targetDb, dorisTable));
             }
         }
@@ -166,6 +158,7 @@ public abstract class DatabaseSync {
             System.out.println("Create table finished.");
             System.exit(0);
         }
+        LOG.info("table mapping: {}", tableMapping);
         config.setString(TABLE_NAME_OPTIONS, getSyncTableList(syncTables));
         DataStreamSource<String> streamSource = buildCdcSource(env);
         if (singleSink) {
@@ -340,9 +333,10 @@ public abstract class DatabaseSync {
         return JsonDebeziumSchemaSerializer.builder()
                 .setDorisOptions(dorisBuilder.build())
                 .setNewSchemaChange(newSchemaChange)
+                .setSchemaChangeMode(schemaChangeMode)
                 .setExecutionOptions(executionOptions)
                 .setTableMapping(tableMapping)
-                .setTableProperties(tableConfig)
+                .setDorisTableConf(dorisTableConfig)
                 .setTargetDatabase(database)
                 .setTargetTablePrefix(tablePrefix)
                 .setTargetTableSuffix(tableSuffix)
@@ -414,6 +408,7 @@ public abstract class DatabaseSync {
      * @param tableBuckets the string of tableBuckets, eg:student:10,student_info:20,student.*:30
      * @return The table name and buckets map. The key is table name, the value is buckets.
      */
+    @Deprecated
     public static Map<String, Integer> getTableBuckets(String tableBuckets) {
         Map<String, Integer> tableBucketsMap = new LinkedHashMap<>();
         String[] tableBucketsArray = tableBuckets.split(",");
@@ -434,6 +429,7 @@ public abstract class DatabaseSync {
      * @param dorisTable the table name need to set buckets
      * @param tableHasSet The buckets table is set
      */
+    @Deprecated
     public void setTableSchemaBuckets(
             Map<String, Integer> tableBucketsMap,
             TableSchema dorisSchema,
@@ -463,29 +459,23 @@ public abstract class DatabaseSync {
         }
     }
 
-    private boolean tryCreateTableIfAbsent(
-            DorisSystem dorisSystem,
-            String targetDb,
-            String dorisTable,
-            SourceSchema schema,
-            Map<String, Integer> tableBucketsMap,
-            Set<String> tableBucketsSet) {
+    private void tryCreateTableIfAbsent(
+            DorisSystem dorisSystem, String targetDb, String dorisTable, SourceSchema schema) {
         if (!dorisSystem.tableExists(targetDb, dorisTable)) {
-            TableSchema dorisSchema = schema.convertTableSchema(tableConfig);
-            dorisSchema.setDatabase(targetDb);
-            dorisSchema.setTable(dorisTable);
-            // set the table buckets of table
-            if (tableBucketsMap != null) {
-                setTableSchemaBuckets(tableBucketsMap, dorisSchema, dorisTable, tableBucketsSet);
-            }
+            TableSchema dorisSchema =
+                    DorisSchemaFactory.createTableSchema(
+                            database,
+                            dorisTable,
+                            schema.getFields(),
+                            schema.getPrimaryKeys(),
+                            dorisTableConfig,
+                            schema.getTableComment());
             try {
                 dorisSystem.createTable(dorisSchema);
-                return true;
             } catch (Exception ex) {
                 handleTableCreationFailure(ex);
             }
         }
-        return false;
     }
 
     private void handleTableCreationFailure(Exception ex) throws DorisSystemException {
@@ -498,6 +488,25 @@ public abstract class DatabaseSync {
         }
     }
 
+    protected Properties getJdbcProperties() {
+        Properties jdbcProps = new Properties();
+        for (Map.Entry<String, String> entry : config.toMap().entrySet()) {
+            String key = entry.getKey();
+            String value = entry.getValue();
+            if (key.startsWith(PROPERTIES_PREFIX)) {
+                jdbcProps.put(key.substring(PROPERTIES_PREFIX.length()), value);
+            }
+        }
+        return jdbcProps;
+    }
+
+    protected String getJdbcUrlTemplate(String initialJdbcUrl, Properties jdbcProperties) {
+        StringBuilder jdbcUrlBuilder = new StringBuilder(initialJdbcUrl);
+        jdbcProperties.forEach(
+                (key, value) -> jdbcUrlBuilder.append("&").append(key).append("=").append(value));
+        return jdbcUrlBuilder.toString();
+    }
+
     public DatabaseSync setEnv(StreamExecutionEnvironment env) {
         this.env = env;
         return this;
@@ -533,13 +542,19 @@ public abstract class DatabaseSync {
         return this;
     }
 
+    @Deprecated
     public DatabaseSync setTableConfig(Map<String, String> tableConfig) {
         if (!CollectionUtil.isNullOrEmpty(tableConfig)) {
-            this.tableConfig = tableConfig;
+            this.dorisTableConfig = new DorisTableConfig(tableConfig);
         }
         return this;
     }
 
+    public DatabaseSync setTableConfig(DorisTableConfig tableConfig) {
+        this.dorisTableConfig = tableConfig;
+        return this;
+    }
+
     public DatabaseSync setSinkConfig(Configuration sinkConfig) {
         this.sinkConfig = sinkConfig;
         return this;
@@ -560,6 +575,15 @@ public abstract class DatabaseSync {
         return this;
     }
 
+    public DatabaseSync setSchemaChangeMode(String schemaChangeMode) {
+        if (org.apache.commons.lang3.StringUtils.isEmpty(schemaChangeMode)) {
+            this.schemaChangeMode = SchemaChangeMode.DEBEZIUM_STRUCTURE.getName();
+            return this;
+        }
+        this.schemaChangeMode = schemaChangeMode.trim();
+        return this;
+    }
+
     public DatabaseSync setSingleSink(boolean singleSink) {
         this.singleSink = singleSink;
         return this;
