@@ -18,6 +18,13 @@
 package org.apache.doris.flink.tools.cdc.mongodb;
 
 import org.apache.flink.api.common.eventtime.WatermarkStrategy;
+import org.apache.flink.cdc.connectors.base.options.SourceOptions;
+import org.apache.flink.cdc.connectors.base.options.StartupOptions;
+import org.apache.flink.cdc.connectors.mongodb.source.MongoDBSource;
+import org.apache.flink.cdc.connectors.mongodb.source.MongoDBSourceBuilder;
+import org.apache.flink.cdc.connectors.mongodb.source.config.MongoDBSourceOptions;
+import org.apache.flink.cdc.connectors.shaded.org.apache.kafka.connect.json.JsonConverterConfig;
+import org.apache.flink.cdc.debezium.JsonDebeziumDeserializationSchema;
 import org.apache.flink.configuration.ConfigOption;
 import org.apache.flink.configuration.ConfigOptions;
 import org.apache.flink.streaming.api.datastream.DataStreamSource;
@@ -30,19 +37,13 @@ import com.mongodb.client.MongoClients;
 import com.mongodb.client.MongoCollection;
 import com.mongodb.client.MongoDatabase;
 import com.mongodb.client.MongoIterable;
-import com.ververica.cdc.connectors.base.options.SourceOptions;
-import com.ververica.cdc.connectors.base.options.StartupOptions;
-import com.ververica.cdc.connectors.mongodb.source.MongoDBSource;
-import com.ververica.cdc.connectors.mongodb.source.MongoDBSourceBuilder;
-import com.ververica.cdc.connectors.mongodb.source.config.MongoDBSourceOptions;
-import com.ververica.cdc.connectors.shaded.org.apache.kafka.connect.json.JsonConverterConfig;
-import com.ververica.cdc.debezium.JsonDebeziumDeserializationSchema;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.doris.flink.catalog.doris.DataModel;
 import org.apache.doris.flink.cfg.DorisExecutionOptions;
 import org.apache.doris.flink.cfg.DorisOptions;
 import org.apache.doris.flink.sink.writer.serializer.DorisRecordSerializer;
 import org.apache.doris.flink.tools.cdc.DatabaseSync;
+import org.apache.doris.flink.tools.cdc.DatabaseSyncConfig;
 import org.apache.doris.flink.tools.cdc.ParsingProcessFunction;
 import org.apache.doris.flink.tools.cdc.SourceSchema;
 import org.apache.doris.flink.tools.cdc.mongodb.serializer.MongoDBJsonDebeziumSchemaSerializer;
@@ -57,14 +58,10 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
-import static com.ververica.cdc.connectors.mongodb.internal.MongoDBEnvelope.encodeValue;
+import static org.apache.flink.cdc.connectors.mongodb.internal.MongoDBEnvelope.encodeValue;
 import static org.apache.flink.util.Preconditions.checkNotNull;
 
 public class MongoDBDatabaseSync extends DatabaseSync {
-
-    private static final String INITIAL_MODE = "initial";
-    private static final String LATEST_OFFSET_MODE = "latest-offset";
-    private static final String TIMESTAMP_MODE = "timestamp";
     public static final ConfigOption<Double> MONGO_CDC_CREATE_SAMPLE_PERCENT =
             ConfigOptions.key("schema.sample-percent")
                     .doubleType()
@@ -161,7 +158,7 @@ public class MongoDBDatabaseSync extends DatabaseSync {
         String password = config.get(MongoDBSourceOptions.PASSWORD);
         String database = config.get(MongoDBSourceOptions.DATABASE);
         // note: just to unify job name, no other use.
-        config.setString("database-name", database);
+        config.setString(DatabaseSyncConfig.DATABASE_NAME, database);
         String collection = config.get(MongoDBSourceOptions.COLLECTION);
         if (StringUtils.isBlank(collection)) {
             collection = config.get(TABLE_NAME);
@@ -181,13 +178,13 @@ public class MongoDBDatabaseSync extends DatabaseSync {
 
         String startupMode = config.get(SourceOptions.SCAN_STARTUP_MODE);
         switch (startupMode.toLowerCase()) {
-            case INITIAL_MODE:
+            case DatabaseSyncConfig.SCAN_STARTUP_MODE_VALUE_INITIAL:
                 mongoDBSourceBuilder.startupOptions(StartupOptions.initial());
                 break;
-            case LATEST_OFFSET_MODE:
+            case DatabaseSyncConfig.SCAN_STARTUP_MODE_VALUE_LATEST_OFFSET:
                 mongoDBSourceBuilder.startupOptions(StartupOptions.latest());
                 break;
-            case TIMESTAMP_MODE:
+            case DatabaseSyncConfig.SCAN_STARTUP_MODE_VALUE_TIMESTAMP:
                 mongoDBSourceBuilder.startupOptions(
                         StartupOptions.timestamp(
                                 config.get(SourceOptions.SCAN_STARTUP_TIMESTAMP_MILLIS)));
@@ -211,7 +208,7 @@ public class MongoDBDatabaseSync extends DatabaseSync {
                 .setDorisOptions(dorisBuilder.build())
                 .setExecutionOptions(executionOptions)
                 .setTableMapping(tableMapping)
-                .setTableProperties(tableConfig)
+                .setTableConf(dorisTableConfig)
                 .setTargetDatabase(database)
                 .build();
     }
