@@ -22,22 +22,29 @@ import org.apache.flink.api.common.RuntimeExecutionMode;
 import org.apache.flink.api.common.restartstrategy.RestartStrategies;
 import org.apache.flink.api.common.time.Deadline;
 import org.apache.flink.core.execution.JobClient;
+import org.apache.flink.runtime.minicluster.RpcServiceSharing;
+import org.apache.flink.runtime.testutils.MiniClusterResourceConfiguration;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
 import org.apache.flink.table.api.bridge.java.StreamTableEnvironment;
+import org.apache.flink.test.util.MiniClusterWithClientResource;
+import org.apache.flink.util.StringUtils;
 
 import com.fasterxml.jackson.databind.ObjectMapper;
-import org.apache.doris.flink.DorisTestBase;
 import org.apache.doris.flink.cfg.DorisExecutionOptions;
 import org.apache.doris.flink.cfg.DorisOptions;
 import org.apache.doris.flink.cfg.DorisReadOptions;
+import org.apache.doris.flink.container.AbstractITCaseService;
+import org.apache.doris.flink.container.ContainerUtils;
+import org.apache.doris.flink.sink.DorisSink.Builder;
 import org.apache.doris.flink.sink.batch.DorisBatchSink;
 import org.apache.doris.flink.sink.writer.serializer.SimpleStringSerializer;
+import org.apache.doris.flink.table.DorisConfigOptions;
 import org.apache.doris.flink.utils.MockSource;
+import org.junit.Rule;
 import org.junit.Test;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
-import java.sql.Connection;
-import java.sql.DriverManager;
-import java.sql.Statement;
 import java.time.Duration;
 import java.util.Arrays;
 import java.util.Collections;
@@ -51,17 +58,30 @@ import static org.apache.flink.api.common.JobStatus.FINISHED;
 import static org.apache.flink.api.common.JobStatus.RUNNING;
 
 /** DorisSink ITCase with csv and arrow format. */
-public class DorisSinkITCase extends DorisTestBase {
+public class DorisSinkITCase extends AbstractITCaseService {
+    private static final Logger LOG = LoggerFactory.getLogger(DorisSinkITCase.class);
     static final String DATABASE = "test_sink";
     static final String TABLE_CSV = "tbl_csv";
     static final String TABLE_JSON = "tbl_json";
     static final String TABLE_JSON_TBL = "tbl_json_tbl";
+    static final String TABLE_TBL_AUTO_REDIRECT = "tbl_tbl_auto_redirect";
     static final String TABLE_CSV_BATCH_TBL = "tbl_csv_batch_tbl";
     static final String TABLE_CSV_BATCH_DS = "tbl_csv_batch_DS";
     static final String TABLE_GROUP_COMMIT = "tbl_group_commit";
+    static final String TABLE_GZ_FORMAT = "tbl_gz_format";
     static final String TABLE_CSV_JM = "tbl_csv_jm";
     static final String TABLE_CSV_TM = "tbl_csv_tm";
 
+    @Rule
+    public final MiniClusterWithClientResource miniClusterResource =
+            new MiniClusterWithClientResource(
+                    new MiniClusterResourceConfiguration.Builder()
+                            .setNumberTaskManagers(1)
+                            .setNumberSlotsPerTaskManager(2)
+                            .setRpcServiceSharing(RpcServiceSharing.DEDICATED)
+                            .withHaLeadershipControl()
+                            .build());
+
     @Test
     public void testSinkCsvFormat() throws Exception {
         initializeTable(TABLE_CSV);
@@ -69,12 +89,20 @@ public class DorisSinkITCase extends DorisTestBase {
         properties.setProperty("column_separator", ",");
         properties.setProperty("line_delimiter", "\n");
         properties.setProperty("format", "csv");
-        submitJob(TABLE_CSV, properties, new String[] {"doris,1"});
+        DorisExecutionOptions.Builder executionBuilder = DorisExecutionOptions.builder();
+        executionBuilder.setLabelPrefix(UUID.randomUUID().toString()).setStreamLoadProp(properties);
+        DorisOptions.Builder dorisBuilder = DorisOptions.builder();
+        dorisBuilder
+                .setFenodes(getFenodes())
+                .setTableIdentifier(DATABASE + "." + TABLE_CSV)
+                .setUsername(getDorisUsername())
+                .setPassword(getDorisPassword());
+        submitJob(dorisBuilder.build(), executionBuilder.build(), new String[] {"doris,1"});
 
         Thread.sleep(10000);
         List<String> expected = Arrays.asList("doris,1");
         String query = String.format("select name,age from %s.%s order by 1", DATABASE, TABLE_CSV);
-        checkResult(expected, query, 2);
+        ContainerUtils.checkResult(getDorisQueryConnection(), LOG, expected, query, 2);
     }
 
     @Test
@@ -92,9 +120,18 @@ public class DorisSinkITCase extends DorisTestBase {
         row2.put("name", "doris2");
         row2.put("age", 2);
 
+        DorisExecutionOptions.Builder executionBuilder = DorisExecutionOptions.builder();
+        executionBuilder.setLabelPrefix(UUID.randomUUID().toString()).setStreamLoadProp(properties);
+        DorisOptions.Builder dorisBuilder = DorisOptions.builder();
+        dorisBuilder
+                .setFenodes(getFenodes())
+                .setTableIdentifier(DATABASE + "." + TABLE_JSON)
+                .setUsername(getDorisUsername())
+                .setPassword(getDorisPassword());
+
         submitJob(
-                TABLE_JSON,
-                properties,
+                dorisBuilder.build(),
+                executionBuilder.build(),
                 new String[] {
                     new ObjectMapper().writeValueAsString(row1),
                     new ObjectMapper().writeValueAsString(row2)
@@ -103,28 +140,22 @@ public class DorisSinkITCase extends DorisTestBase {
         Thread.sleep(10000);
         List<String> expected = Arrays.asList("doris1,1", "doris2,2");
         String query = String.format("select name,age from %s.%s order by 1", DATABASE, TABLE_JSON);
-        checkResult(expected, query, 2);
+        ContainerUtils.checkResult(getDorisQueryConnection(), LOG, expected, query, 2);
     }
 
-    public void submitJob(String table, Properties properties, String[] records) throws Exception {
+    private void submitJob(
+            DorisOptions dorisOptions, DorisExecutionOptions executionOptions, String[] records)
+            throws Exception {
         StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
         env.setRuntimeMode(RuntimeExecutionMode.BATCH);
-        DorisSink.Builder<String> builder = DorisSink.builder();
+        env.setParallelism(DEFAULT_PARALLELISM);
+        Builder<String> builder = DorisSink.builder();
         final DorisReadOptions.Builder readOptionBuilder = DorisReadOptions.builder();
 
-        DorisOptions.Builder dorisBuilder = DorisOptions.builder();
-        dorisBuilder
-                .setFenodes(getFenodes())
-                .setTableIdentifier(DATABASE + "." + table)
-                .setUsername(USERNAME)
-                .setPassword(PASSWORD);
-        DorisExecutionOptions.Builder executionBuilder = DorisExecutionOptions.builder();
-        executionBuilder.setLabelPrefix(UUID.randomUUID().toString()).setStreamLoadProp(properties);
-
         builder.setDorisReadOptions(readOptionBuilder.build())
-                .setDorisExecutionOptions(executionBuilder.build())
+                .setDorisExecutionOptions(executionOptions)
                 .setSerializer(new SimpleStringSerializer())
-                .setDorisOptions(dorisBuilder.build());
+                .setDorisOptions(dorisOptions);
 
         env.fromElements(records).sinkTo(builder.build());
         env.execute();
@@ -134,7 +165,7 @@ public class DorisSinkITCase extends DorisTestBase {
     public void testTableSinkJsonFormat() throws Exception {
         initializeTable(TABLE_JSON_TBL);
         final StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
-        env.setParallelism(1);
+        env.setParallelism(DEFAULT_PARALLELISM);
         env.setRuntimeMode(RuntimeExecutionMode.BATCH);
         final StreamTableEnvironment tEnv = StreamTableEnvironment.create(env);
 
@@ -144,10 +175,10 @@ public class DorisSinkITCase extends DorisTestBase {
                                 + " name STRING,"
                                 + " age INT"
                                 + ") WITH ("
-                                + " 'connector' = 'doris',"
+                                + " 'connector' = '"
+                                + DorisConfigOptions.IDENTIFIER
+                                + "',"
                                 + " 'fenodes' = '%s',"
-                                + " 'benodes' = '%s',"
-                                + " 'auto-redirect' = 'false',"
                                 + " 'table.identifier' = '%s',"
                                 + " 'username' = '%s',"
                                 + " 'password' = '%s',"
@@ -165,10 +196,9 @@ public class DorisSinkITCase extends DorisTestBase {
                                 + "'"
                                 + ")",
                         getFenodes(),
-                        getBenodes(),
                         DATABASE + "." + TABLE_JSON_TBL,
-                        USERNAME,
-                        PASSWORD);
+                        getDorisUsername(),
+                        getDorisPassword());
         tEnv.executeSql(sinkDDL);
         tEnv.executeSql("INSERT INTO doris_sink SELECT 'doris',1 union all SELECT 'flink',2");
 
@@ -176,14 +206,18 @@ public class DorisSinkITCase extends DorisTestBase {
         List<String> expected = Arrays.asList("doris,1", "flink,2");
         String query =
                 String.format("select name,age from %s.%s order by 1", DATABASE, TABLE_JSON_TBL);
-        checkResult(expected, query, 2);
+        ContainerUtils.checkResult(getDorisQueryConnection(), LOG, expected, query, 2);
     }
 
     @Test
-    public void testTableBatch() throws Exception {
-        initializeTable(TABLE_CSV_BATCH_TBL);
+    public void testTableSinkAutoRedirectFalse() throws Exception {
+        if (StringUtils.isNullOrWhitespaceOnly(getBenodes())) {
+            LOG.info("benodes is empty, skip the test.");
+            return;
+        }
+        initializeTable(TABLE_TBL_AUTO_REDIRECT);
         final StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
-        env.setParallelism(1);
+        env.setParallelism(DEFAULT_PARALLELISM);
         env.setRuntimeMode(RuntimeExecutionMode.BATCH);
         final StreamTableEnvironment tEnv = StreamTableEnvironment.create(env);
 
@@ -193,7 +227,51 @@ public class DorisSinkITCase extends DorisTestBase {
                                 + " name STRING,"
                                 + " age INT"
                                 + ") WITH ("
-                                + " 'connector' = 'doris',"
+                                + " 'connector' = '"
+                                + DorisConfigOptions.IDENTIFIER
+                                + "',"
+                                + " 'fenodes' = '%s',"
+                                + " 'benodes' = '%s',"
+                                + " 'auto-redirect' = 'false',"
+                                + " 'table.identifier' = '%s',"
+                                + " 'username' = '%s',"
+                                + " 'password' = '%s',"
+                                + " 'sink.label-prefix' = 'doris_sink"
+                                + UUID.randomUUID()
+                                + "'"
+                                + ")",
+                        getFenodes(),
+                        getBenodes(),
+                        DATABASE + "." + TABLE_TBL_AUTO_REDIRECT,
+                        getDorisUsername(),
+                        getDorisPassword());
+        tEnv.executeSql(sinkDDL);
+        tEnv.executeSql("INSERT INTO doris_sink SELECT 'doris',1 union all SELECT 'flink',2");
+
+        Thread.sleep(10000);
+        List<String> expected = Arrays.asList("doris,1", "flink,2");
+        String query =
+                String.format("select name,age from %s.%s order by 1", DATABASE, TABLE_JSON_TBL);
+        ContainerUtils.checkResult(getDorisQueryConnection(), LOG, expected, query, 2);
+    }
+
+    @Test
+    public void testTableBatch() throws Exception {
+        initializeTable(TABLE_CSV_BATCH_TBL);
+        final StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
+        env.setParallelism(DEFAULT_PARALLELISM);
+        env.setRuntimeMode(RuntimeExecutionMode.BATCH);
+        final StreamTableEnvironment tEnv = StreamTableEnvironment.create(env);
+
+        String sinkDDL =
+                String.format(
+                        "CREATE TABLE doris_sink_batch ("
+                                + " name STRING,"
+                                + " age INT"
+                                + ") WITH ("
+                                + " 'connector' = '"
+                                + DorisConfigOptions.IDENTIFIER
+                                + "',"
                                 + " 'fenodes' = '%s',"
                                 + " 'table.identifier' = '%s',"
                                 + " 'username' = '%s',"
@@ -207,23 +285,23 @@ public class DorisSinkITCase extends DorisTestBase {
                                 + " 'sink.enable.batch-mode' = 'true',"
                                 + " 'sink.enable-delete' = 'true',"
                                 + " 'sink.flush.queue-size' = '2',"
-                                + " 'sink.buffer-flush.max-rows' = '1',"
-                                + " 'sink.buffer-flush.max-bytes' = '5',"
-                                + " 'sink.buffer-flush.interval' = '10s'"
+                                + " 'sink.buffer-flush.max-rows' = '10000',"
+                                + " 'sink.buffer-flush.max-bytes' = '10MB',"
+                                + " 'sink.buffer-flush.interval' = '1s'"
                                 + ")",
                         getFenodes(),
                         DATABASE + "." + TABLE_CSV_BATCH_TBL,
-                        USERNAME,
-                        PASSWORD);
+                        getDorisUsername(),
+                        getDorisPassword());
         tEnv.executeSql(sinkDDL);
-        tEnv.executeSql("INSERT INTO doris_sink SELECT 'doris',1 union all SELECT 'flink',2");
+        tEnv.executeSql("INSERT INTO doris_sink_batch SELECT 'doris',1 union all SELECT 'flink',2");
 
-        Thread.sleep(10000);
+        Thread.sleep(20000);
         List<String> expected = Arrays.asList("doris,1", "flink,2");
         String query =
                 String.format(
                         "select name,age from %s.%s order by 1", DATABASE, TABLE_CSV_BATCH_TBL);
-        checkResult(expected, query, 2);
+        ContainerUtils.checkResult(getDorisQueryConnection(), LOG, expected, query, 2);
     }
 
     @Test
@@ -231,14 +309,15 @@ public class DorisSinkITCase extends DorisTestBase {
         initializeTable(TABLE_CSV_BATCH_DS);
         StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
         env.setRuntimeMode(RuntimeExecutionMode.BATCH);
+        env.setParallelism(DEFAULT_PARALLELISM);
         DorisBatchSink.Builder<String> builder = DorisBatchSink.builder();
 
         DorisOptions.Builder dorisBuilder = DorisOptions.builder();
         dorisBuilder
                 .setFenodes(getFenodes())
                 .setTableIdentifier(DATABASE + "." + TABLE_CSV_BATCH_DS)
-                .setUsername(USERNAME)
-                .setPassword(PASSWORD);
+                .setUsername(getDorisUsername())
+                .setPassword(getDorisPassword());
         Properties properties = new Properties();
         properties.setProperty("column_separator", ",");
         properties.setProperty("line_delimiter", "\n");
@@ -247,8 +326,9 @@ public class DorisSinkITCase extends DorisTestBase {
         executionBuilder
                 .setLabelPrefix(UUID.randomUUID().toString())
                 .setStreamLoadProp(properties)
-                .setBufferFlushMaxBytes(1)
-                .setBufferFlushMaxRows(10);
+                .setBufferFlushMaxBytes(10485760)
+                .setBufferFlushMaxRows(10000)
+                .setBufferFlushIntervalMs(1000);
 
         builder.setDorisExecutionOptions(executionBuilder.build())
                 .setSerializer(new SimpleStringSerializer())
@@ -257,19 +337,19 @@ public class DorisSinkITCase extends DorisTestBase {
         env.fromElements("doris,1", "flink,2").sinkTo(builder.build());
         env.execute();
 
-        Thread.sleep(10000);
+        Thread.sleep(20000);
         List<String> expected = Arrays.asList("doris,1", "flink,2");
         String query =
                 String.format(
                         "select name,age from %s.%s order by 1", DATABASE, TABLE_CSV_BATCH_DS);
-        checkResult(expected, query, 2);
+        ContainerUtils.checkResult(getDorisQueryConnection(), LOG, expected, query, 2);
     }
 
     @Test
     public void testTableGroupCommit() throws Exception {
         initializeTable(TABLE_GROUP_COMMIT);
         final StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
-        env.setParallelism(1);
+        env.setParallelism(DEFAULT_PARALLELISM);
         env.setRuntimeMode(RuntimeExecutionMode.BATCH);
         final StreamTableEnvironment tEnv = StreamTableEnvironment.create(env);
 
@@ -279,7 +359,9 @@ public class DorisSinkITCase extends DorisTestBase {
                                 + " name STRING,"
                                 + " age INT"
                                 + ") WITH ("
-                                + " 'connector' = 'doris',"
+                                + " 'connector' = '"
+                                + DorisConfigOptions.IDENTIFIER
+                                + "',"
                                 + " 'fenodes' = '%s',"
                                 + " 'table.identifier' = '%s',"
                                 + " 'username' = '%s',"
@@ -294,14 +376,14 @@ public class DorisSinkITCase extends DorisTestBase {
                                 + " 'sink.enable.batch-mode' = 'true',"
                                 + " 'sink.enable-delete' = 'true',"
                                 + " 'sink.flush.queue-size' = '2',"
-                                + " 'sink.buffer-flush.max-rows' = '3',"
-                                + " 'sink.buffer-flush.max-bytes' = '5000',"
-                                + " 'sink.buffer-flush.interval' = '10s'"
+                                + " 'sink.buffer-flush.max-rows' = '10000',"
+                                + " 'sink.buffer-flush.max-bytes' = '10MB',"
+                                + " 'sink.buffer-flush.interval' = '1s'"
                                 + ")",
                         getFenodes(),
                         DATABASE + "." + TABLE_GROUP_COMMIT,
-                        USERNAME,
-                        PASSWORD);
+                        getDorisUsername(),
+                        getDorisPassword());
         tEnv.executeSql(sinkDDL);
         tEnv.executeSql(
                 "INSERT INTO doris_group_commit_sink SELECT 'doris',1 union all  SELECT 'group_commit',2 union all  SELECT 'flink',3");
@@ -311,15 +393,58 @@ public class DorisSinkITCase extends DorisTestBase {
         String query =
                 String.format(
                         "select name,age from %s.%s order by 1", DATABASE, TABLE_GROUP_COMMIT);
-        //
-        checkResult(expected, query, 2);
+        ContainerUtils.checkResult(getDorisQueryConnection(), LOG, expected, query, 2);
+    }
+
+    @Test
+    public void testTableGzFormat() throws Exception {
+        initializeTable(TABLE_GZ_FORMAT);
+        final StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
+        env.setParallelism(DEFAULT_PARALLELISM);
+        env.setRuntimeMode(RuntimeExecutionMode.BATCH);
+        final StreamTableEnvironment tEnv = StreamTableEnvironment.create(env);
+
+        String sinkDDL =
+                String.format(
+                        "CREATE TABLE doris_gz_format_sink ("
+                                + " name STRING,"
+                                + " age INT"
+                                + ") WITH ("
+                                + " 'connector' = '"
+                                + DorisConfigOptions.IDENTIFIER
+                                + "',"
+                                + " 'fenodes' = '%s',"
+                                + " 'table.identifier' = '%s',"
+                                + " 'username' = '%s',"
+                                + " 'password' = '%s',"
+                                + " 'sink.label-prefix' = '"
+                                + UUID.randomUUID()
+                                + "',"
+                                + " 'sink.properties.column_separator' = '\\x01',"
+                                + " 'sink.properties.line_delimiter' = '\\x02',"
+                                + " 'sink.properties.compress_type' = 'gz'"
+                                + ")",
+                        getFenodes(),
+                        DATABASE + "." + TABLE_GZ_FORMAT,
+                        getDorisUsername(),
+                        getDorisPassword());
+        tEnv.executeSql(sinkDDL);
+        tEnv.executeSql(
+                "INSERT INTO doris_gz_format_sink SELECT 'doris',1 union all  SELECT 'flink',2");
+
+        Thread.sleep(25000);
+        List<String> expected = Arrays.asList("doris,1", "flink,2");
+        String query =
+                String.format("select name,age from %s.%s order by 1", DATABASE, TABLE_GZ_FORMAT);
+        ContainerUtils.checkResult(getDorisQueryConnection(), LOG, expected, query, 2);
     }
 
     @Test
     public void testJobManagerFailoverSink() throws Exception {
+        LOG.info("start to test JobManagerFailoverSink.");
         initializeFailoverTable(TABLE_CSV_JM);
         StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
-        env.setParallelism(2);
+        env.setParallelism(DEFAULT_PARALLELISM);
         env.enableCheckpointing(10000);
         env.setRestartStrategy(RestartStrategies.fixedDelayRestart(3, 0));
 
@@ -330,8 +455,8 @@ public class DorisSinkITCase extends DorisTestBase {
         dorisBuilder
                 .setFenodes(getFenodes())
                 .setTableIdentifier(DATABASE + "." + TABLE_CSV_JM)
-                .setUsername(USERNAME)
-                .setPassword(PASSWORD);
+                .setUsername(getDorisUsername())
+                .setPassword(getDorisPassword());
         DorisExecutionOptions.Builder executionBuilder = DorisExecutionOptions.builder();
         Properties properties = new Properties();
         properties.setProperty("column_separator", ",");
@@ -360,23 +485,26 @@ public class DorisSinkITCase extends DorisTestBase {
         triggerFailover(
                 FailoverType.JM, jobID, miniClusterResource.getMiniCluster(), () -> sleepMs(100));
 
+        LOG.info("Waiting the JobManagerFailoverSink job to be finished. jobId={}", jobID);
         waitForJobStatus(
                 jobClient,
                 Collections.singletonList(FINISHED),
                 Deadline.fromNow(Duration.ofSeconds(120)));
 
+        LOG.info("Will check job manager failover sink result.");
         List<String> expected =
                 Arrays.asList("1,0", "1,1", "2,0", "2,1", "3,0", "3,1", "4,0", "4,1", "5,0", "5,1");
         String query =
                 String.format("select id,task_id from %s.%s order by 1,2", DATABASE, TABLE_CSV_JM);
-        checkResult(expected, query, 2);
+        ContainerUtils.checkResult(getDorisQueryConnection(), LOG, expected, query, 2);
     }
 
     @Test
     public void testTaskManagerFailoverSink() throws Exception {
+        LOG.info("start to test TaskManagerFailoverSink.");
         initializeFailoverTable(TABLE_CSV_TM);
         StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
-        env.setParallelism(2);
+        env.setParallelism(DEFAULT_PARALLELISM);
         env.enableCheckpointing(10000);
         env.setRestartStrategy(RestartStrategies.fixedDelayRestart(3, 0));
 
@@ -387,8 +515,8 @@ public class DorisSinkITCase extends DorisTestBase {
         dorisBuilder
                 .setFenodes(getFenodes())
                 .setTableIdentifier(DATABASE + "." + TABLE_CSV_TM)
-                .setUsername(USERNAME)
-                .setPassword(PASSWORD);
+                .setUsername(getDorisUsername())
+                .setPassword(getDorisPassword());
         DorisExecutionOptions.Builder executionBuilder = DorisExecutionOptions.builder();
         Properties properties = new Properties();
         properties.setProperty("column_separator", ",");
@@ -414,62 +542,51 @@ public class DorisSinkITCase extends DorisTestBase {
         triggerFailover(
                 FailoverType.TM, jobID, miniClusterResource.getMiniCluster(), () -> sleepMs(100));
 
+        LOG.info("Waiting the TaskManagerFailoverSink job to be finished. jobId={}", jobID);
         waitForJobStatus(
                 jobClient,
                 Collections.singletonList(FINISHED),
                 Deadline.fromNow(Duration.ofSeconds(120)));
 
+        LOG.info("Will check task manager failover sink result.");
         List<String> expected =
                 Arrays.asList("1,0", "1,1", "2,0", "2,1", "3,0", "3,1", "4,0", "4,1", "5,0", "5,1");
         String query =
                 String.format("select id,task_id from %s.%s order by 1,2", DATABASE, TABLE_CSV_TM);
-        checkResult(expected, query, 2);
+        ContainerUtils.checkResult(getDorisQueryConnection(), LOG, expected, query, 2);
     }
 
-    private void sleepMs(long millis) {
-        try {
-            Thread.sleep(millis);
-        } catch (InterruptedException ignored) {
-        }
+    private void initializeTable(String table) {
+        ContainerUtils.executeSQLStatement(
+                getDorisQueryConnection(),
+                LOG,
+                String.format("CREATE DATABASE IF NOT EXISTS %s", DATABASE),
+                String.format("DROP TABLE IF EXISTS %s.%s", DATABASE, table),
+                String.format(
+                        "CREATE TABLE %s.%s ( \n"
+                                + "`name` varchar(256),\n"
+                                + "`age` int\n"
+                                + ") DISTRIBUTED BY HASH(`name`) BUCKETS 1\n"
+                                + "PROPERTIES (\n"
+                                + "\"replication_num\" = \"1\"\n"
+                                + ")\n",
+                        DATABASE, table));
     }
 
-    private void initializeTable(String table) throws Exception {
-        try (Connection connection =
-                        DriverManager.getConnection(
-                                String.format(URL, DORIS_CONTAINER.getHost()), USERNAME, PASSWORD);
-                Statement statement = connection.createStatement()) {
-            statement.execute(String.format("CREATE DATABASE IF NOT EXISTS %s", DATABASE));
-            statement.execute(String.format("DROP TABLE IF EXISTS %s.%s", DATABASE, table));
-            statement.execute(
-                    String.format(
-                            "CREATE TABLE %s.%s ( \n"
-                                    + "`name` varchar(256),\n"
-                                    + "`age` int\n"
-                                    + ") DISTRIBUTED BY HASH(`name`) BUCKETS 1\n"
-                                    + "PROPERTIES (\n"
-                                    + "\"replication_num\" = \"1\"\n"
-                                    + ")\n",
-                            DATABASE, table));
-        }
-    }
-
-    private void initializeFailoverTable(String table) throws Exception {
-        try (Connection connection =
-                        DriverManager.getConnection(
-                                String.format(URL, DORIS_CONTAINER.getHost()), USERNAME, PASSWORD);
-                Statement statement = connection.createStatement()) {
-            statement.execute(String.format("CREATE DATABASE IF NOT EXISTS %s", DATABASE));
-            statement.execute(String.format("DROP TABLE IF EXISTS %s.%s", DATABASE, table));
-            statement.execute(
-                    String.format(
-                            "CREATE TABLE %s.%s ( \n"
-                                    + "`id` int,\n"
-                                    + "`task_id` int\n"
-                                    + ") DISTRIBUTED BY HASH(`id`) BUCKETS 1\n"
-                                    + "PROPERTIES (\n"
-                                    + "\"replication_num\" = \"1\"\n"
-                                    + ")\n",
-                            DATABASE, table));
-        }
+    private void initializeFailoverTable(String table) {
+        ContainerUtils.executeSQLStatement(
+                getDorisQueryConnection(),
+                LOG,
+                String.format("CREATE DATABASE IF NOT EXISTS %s", DATABASE),
+                String.format("DROP TABLE IF EXISTS %s.%s", DATABASE, table),
+                String.format(
+                        "CREATE TABLE %s.%s ( \n"
+                                + "`id` int,\n"
+                                + "`task_id` int\n"
+                                + ") DISTRIBUTED BY HASH(`id`) BUCKETS 1\n"
+                                + "PROPERTIES (\n"
+                                + "\"replication_num\" = \"1\"\n"
+                                + ")\n",
+                        DATABASE, table));
     }
 }
